-module(myapp_sup).
-behaviour(supervisor).

-export([start_link/0, init/1]).


start_link() ->
  supervisor:start_link({local, ?MODULE}, ?MODULE, []).


start_pool() ->
  Params = #{host => application:get_env(myapp, pgs_host, "undefined"),
    port => application:get_env(myapp, pgs_port, 1),
    username => application:get_env(myapp, pgs_user, "undefined"),
    password => application:get_env(myapp, pgs_pass, "undefined"),
    database => application:get_env(myapp, pgs_db, "undefined")},
  
  case epgsql_pool:start(my_pool, 100, 100, Params) of
    {ok, _} ->
      io:format("~p~n", ["pg_pool start !!"]),
      ok;
    Z ->
      io:format("Pool start err: ~p~n~p~n", ["err db connect", Z]),
      err
  end.


init(_Args) ->
  ets:new(events_table, [set, named_table, { keypos, 1 }, public, {write_concurrency, true}]),
  
  {ok, _} = application:ensure_all_started(epgsql_pool),
  
  spawn(fun() -> timer:sleep(1000), start_pool() end),
  
  Procs = [
    #{id => worker_1,
      start => {myapp_events, start_link, []},
      restart => permanent,
      type => worker,
      modules => [myapp_events]},
    
    #{id => worker_2,
      start => {myapp_events2, start_link, []},
      restart => permanent,
      type => worker,
      modules => [myapp_events2]} ],
  
  {ok, { #{strategy => one_for_one, intensity => 10, period => 100}, Procs}}.

